@@ -10,6 +10,7 @@
 #' @param start sequence's initial value
 #' @param step sequence's step size
 #' @return an iterator that returns the mapped values from the sequence
+#' @aliases itabulate
 #'
 #' @examples
 #' it <- itabulate(f=function(x) x + 1)
@@ -24,7 +25,7 @@
 #' it4 <- itabulate(exp, start=6, step=-2)
 #' take(it4, 4) # exp(c(6, 4, 2, 0))
 #'
-itabulate <- function(f, start=1, step=1) {
+i_tabulate <- function(f, start=1, step=1) {
   start <- as.numeric(start)
   step <- as.numeric(step)
 
@@ -37,3 +38,6 @@ itabulate <- function(f, start=1, step=1) {
 
   i_apply(iseq(from=start, by=step), f)
 }
+
+#' @export
+itabulate <- i_tabulate
